summaryrefslogtreecommitdiffstats
path: root/ksayit/src/ksayit.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 15:09:56 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 15:09:56 -0600
commit5ca50f0ef6000d132b45fc6a50cf3062245bd070 (patch)
tree99c6b7de89d289e0a80ec21f7525dc514bc759d1 /ksayit/src/ksayit.h
parent722a076e84b860a947f4c68417db82526b03b1a1 (diff)
downloadtdeaccessibility-5ca50f0ef6000d132b45fc6a50cf3062245bd070.tar.gz
tdeaccessibility-5ca50f0ef6000d132b45fc6a50cf3062245bd070.zip
Rename a number of classes to enhance compatibility with KDE4
Diffstat (limited to 'ksayit/src/ksayit.h')
-rw-r--r--ksayit/src/ksayit.h44
1 files changed, 22 insertions, 22 deletions
diff --git a/ksayit/src/ksayit.h b/ksayit/src/ksayit.h
index d1150bf..451cf36 100644
--- a/ksayit/src/ksayit.h
+++ b/ksayit/src/ksayit.h
@@ -57,15 +57,15 @@ class KSayItBookmarkHandler;
* The base class for KSayIt application windows. It sets up the main
* window and reads the config file as well as providing a menubar, toolbar
* and statusbar. An instance of KSayItView creates the center view.
* KSayItApp reimplements the methods that KMainWindow provides for main window handling and supports
* full session management as well as using KActions.
* @see KMainWindow
* @see TDEApplication
* @see TDEConfig
*
* @author Robert Vogl
*/
-class KSayItApp : public KMainWindow, public DCOPObject
+class KSayItApp : public TDEMainWindow, public DCOPObject
{
Q_OBJECT
//
@@ -276,7 +276,7 @@ private: // Methods
*/
void readOptions();
- /** initializes the KActions of the application */
+ /** initializes the TDEActions of the application */
void initActions();
/** sets up the statusbar for the main window by initialzing a statuslabel.
@@ -331,23 +331,23 @@ private:
KSayItBookmarkHandler *bkHandler;
KBookmarkMenu *bkMenu;
- // KAction pointers
- KToggleAction *statusBarAction;
- KAction *say;
- KAction *pause;
- KAction *shutup;
- KAction *next_sentence;
- KAction *prev_sentence;
- KAction *clear;
- KAction *copy;
- KAction *cut;
- KAction *paste;
- KAction *open;
- KAction *save;
- KAction *saveAs;
- KAction *preferences;
- KToggleAction *edit;
- KActionMenu *bookmarkmenu;
+ // TDEAction pointers
+ TDEToggleAction *statusBarAction;
+ TDEAction *say;
+ TDEAction *pause;
+ TDEAction *shutup;
+ TDEAction *next_sentence;
+ TDEAction *prev_sentence;
+ TDEAction *clear;
+ TDEAction *copy;
+ TDEAction *cut;
+ TDEAction *paste;
+ TDEAction *open;
+ TDEAction *save;
+ TDEAction *saveAs;
+ TDEAction *preferences;
+ TDEToggleAction *edit;
+ TDEActionMenu *bookmarkmenu;
// Misc stuff
TQClipboard *cb;
@@ -57,15 +57,15 @@ class KSayItBookmarkHandler;
* window and reads the config file as well as providing a menubar, toolbar
* and statusbar. An instance of KSayItView creates the center view.
- * KSayItApp reimplements the methods that KMainWindow provides for main window handling and supports
- * full session management as well as using KActions.
- * @see KMainWindow
+ * KSayItApp reimplements the methods that TDEMainWindow provides for main window handling and supports
+ * full session management as well as using TDEActions.
+ * @see TDEMainWindow
* @see TDEApplication
* @see TDEConfig